@@ -3,6 +3,7 @@ package Padre::Document::WebGUI::Asset::Snippet;
 use 5.008;
 use strict;
 use warnings;
+use Padre::Debug;
 use Padre::Document::WebGUI::Asset;
 
 our @ISA = 'Padre::Document::WebGUI::Asset';
@@ -11,7 +12,7 @@ our @ISA = 'Padre::Document::WebGUI::Asset';
 sub lexer {
     my $self     = shift;
     my $mimetype = $self->asset->{mimetype};
-    Padre::Util::debug("Snippet mimetype: $mimetype");
+    TRACE("Snippet mimetype: $mimetype") if DEBUG;
     Padre::MimeTypes->get_lexer( $mimetype || 'text/html' );
 }
 
